'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _StyleSheet = require('../models/StyleSheet');

var _StyleSheet2 = _interopRequireDefault(_StyleSheet);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var LIMIT = 200;

exports.default = function () {
  var generatedClasses = {};
  var warningSeen = false;

  return function (className, displayName) {
    if (!warningSeen) {
      generatedClasses[className] = true;
      if (Object.keys(generatedClasses).length >= LIMIT) {
        var latestRule = _StyleSheet2.default.rules().find(function (s) {
          return s.selectorText && s.selectorText.indexOf('.' + className) !== -1;
        });
        // Unable to find latestRule in test environment.
        /* eslint-disable no-console, prefer-template */
        console.warn('Over ' + LIMIT + ' classes were generated for component ' + displayName + '. ' + 'Consider using style property for frequently changed styles.\n' + 'Example:\n' + '  const StyledComp = styled.div`width: 100%;`\n' + '  <StyledComp style={{ background: background }} />' + (latestRule ? '\nLatest generated class: ' + latestRule.cssText : ''));
        warningSeen = true;
        generatedClasses = {};
      }
    }
  };
};

module.exports = exports['default'];